@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::ClassStartup;
 
 our $DATE = '2016-03-29'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -35,7 +35,7 @@ Bencher::Scenario::Accessors::ClassStartup - Benchmark startup of classes using
 
 =head1 VERSION
 
-This document describes version 0.01 of Bencher::Scenario::Accessors::ClassStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-29.
+This document describes version 0.02 of Bencher::Scenario::Accessors::ClassStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-29.
 
 =head1 SYNOPSIS
 
@@ -75,57 +75,21 @@ L<Perl::Examples::Accessors::Scalar> 0.03
 
 =over
 
-=item * Perl::Examples::Accessors::ClassXSAccessorArray (perl_code)
-
-L<Perl::Examples::Accessors::ClassXSAccessorArray>
-
-
-
-=item * Perl::Examples::Accessors::ClassAccessor (perl_code)
-
-L<Perl::Examples::Accessors::ClassAccessor>
-
-
-
-=item * Perl::Examples::Accessors::Hash (perl_code)
-
-L<Perl::Examples::Accessors::Hash>
-
-
-
-=item * Perl::Examples::Accessors::Scalar (perl_code)
-
-L<Perl::Examples::Accessors::Scalar>
-
-
-
-=item * Perl::Examples::Accessors::ClassAccessorArray (perl_code)
-
-L<Perl::Examples::Accessors::ClassAccessorArray>
-
-
-
 =item * Perl::Examples::Accessors::Moose (perl_code)
 
 L<Perl::Examples::Accessors::Moose>
 
 
 
-=item * Perl::Examples::Accessors::Array (perl_code)
-
-L<Perl::Examples::Accessors::Array>
-
-
-
 =item * Perl::Examples::Accessors::ClassXSAccessor (perl_code)
 
 L<Perl::Examples::Accessors::ClassXSAccessor>
 
 
 
-=item * Perl::Examples::Accessors::Mo (perl_code)
+=item * Perl::Examples::Accessors::Hash (perl_code)
 
-L<Perl::Examples::Accessors::Mo>
+L<Perl::Examples::Accessors::Hash>
 
 
 
@@ -135,12 +99,48 @@ L<Perl::Examples::Accessors::Mouse>
 
 
 
+=item * Perl::Examples::Accessors::Array (perl_code)
+
+L<Perl::Examples::Accessors::Array>
+
+
+
+=item * Perl::Examples::Accessors::ClassXSAccessorArray (perl_code)
+
+L<Perl::Examples::Accessors::ClassXSAccessorArray>
+
+
+
+=item * Perl::Examples::Accessors::Scalar (perl_code)
+
+L<Perl::Examples::Accessors::Scalar>
+
+
+
+=item * Perl::Examples::Accessors::Mo (perl_code)
+
+L<Perl::Examples::Accessors::Mo>
+
+
+
 =item * Perl::Examples::Accessors::Moo (perl_code)
 
 L<Perl::Examples::Accessors::Moo>
 
 
 
+=item * Perl::Examples::Accessors::ClassAccessor (perl_code)
+
+L<Perl::Examples::Accessors::ClassAccessor>
+
+
+
+=item * Perl::Examples::Accessors::ClassAccessorArray (perl_code)
+
+L<Perl::Examples::Accessors::ClassAccessorArray>
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
@@ -152,18 +152,18 @@ Benchmark with default options (C<< bencher -m Accessors::ClassStartup >>):
  +-------------------------------------------------+-----------+------------------------+------------+---------+---------+
  | participant                                     | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
  +-------------------------------------------------+-----------+------------------------+------------+---------+---------+
- | Perl::Examples::Accessors::Moose                | 1.8e+02   | 175                    | 1          | 0.00077 | 20      |
- | Perl::Examples::Accessors::Moo                  | 32        | 27                     | 5.7        | 8.1e-05 | 20      |
- | Perl::Examples::Accessors::Mouse                | 26        | 21                     | 7          | 3.8e-05 | 21      |
- | Perl::Examples::Accessors::ClassXSAccessorArray | 13        | 8                      | 14         | 0.00011 | 20      |
- | Perl::Examples::Accessors::ClassAccessor        | 13        | 8                      | 14         | 2.5e-05 | 20      |
- | Perl::Examples::Accessors::ClassXSAccessor      | 12        | 7                      | 15         | 8.1e-05 | 20      |
- | Perl::Examples::Accessors::ClassAccessorArray   | 7.3       | 2.3                    | 25         | 2.6e-05 | 23      |
- | Perl::Examples::Accessors::Mo                   | 7.1       | 2.1                    | 26         | 4.4e-05 | 21      |
- | perl -e1 (baseline)                             | 5         | 0                      | 3e+01      | 5.4e-05 | 25      |
- | Perl::Examples::Accessors::Hash                 | 5.3       | 0.3                    | 34         | 9.6e-06 | 20      |
- | Perl::Examples::Accessors::Scalar               | 5         | 0                      | 4e+01      | 7.2e-05 | 21      |
- | Perl::Examples::Accessors::Array                | 5         | 0                      | 37         | 3.9e-05 | 20      |
+ | Perl::Examples::Accessors::Moose                | 1.9e+02   | 185                    | 1          | 0.00079 | 21      |
+ | Perl::Examples::Accessors::Moo                  | 34        | 29                     | 5.6        | 0.00019 | 20      |
+ | Perl::Examples::Accessors::Mouse                | 27        | 22                     | 7.1        | 6.9e-05 | 20      |
+ | Perl::Examples::Accessors::ClassXSAccessorArray | 13        | 8                      | 15         | 3.6e-05 | 20      |
+ | Perl::Examples::Accessors::ClassAccessor        | 12        | 7                      | 15         | 4.5e-05 | 20      |
+ | Perl::Examples::Accessors::ClassXSAccessor      | 12        | 7                      | 15         | 5.1e-05 | 20      |
+ | Perl::Examples::Accessors::Mo                   | 7.2       | 2.2                    | 26         | 6.1e-05 | 20      |
+ | Perl::Examples::Accessors::ClassAccessorArray   | 7.2       | 2.2                    | 26         | 5.1e-05 | 20      |
+ | perl -e1 (baseline)                             | 5         | 0                      | 4e+01      | 7.9e-05 | 20      |
+ | Perl::Examples::Accessors::Array                | 4.9       | -0.0999999999999996    | 38         | 3.9e-05 | 21      |
+ | Perl::Examples::Accessors::Hash                 | 4.7       | -0.3                   | 40         | 3.3e-05 | 20      |
+ | Perl::Examples::Accessors::Scalar               | 4.7       | -0.3                   | 40         | 2.1e-05 | 20      |
  +-------------------------------------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
