@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::Construction;
 
 our $DATE = '2016-03-29'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -21,6 +21,7 @@ our $scenario = {
             };
         } keys %$classes,
     ],
+    include_result_size => 1,
 };
 
 1;
@@ -38,7 +39,7 @@ Bencher::Scenario::Accessors::Construction - Benchmark object construction
 
 =head1 VERSION
 
-This document describes version 0.01 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-29.
+This document describes version 0.02 of Bencher::Scenario::Accessors::Construction (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-29.
 
 =head1 SYNOPSIS
 
@@ -82,46 +83,6 @@ L<Perl::Examples::Accessors::Scalar> 0.03
 
 =over
 
-=item * Class::XSAccessor::Array (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassXSAccessorArray->new
-
-
-
-=item * Class::Accessor (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassAccessor->new
-
-
-
-=item * raw-hash (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Hash->new
-
-
-
-=item * raw-scalar (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Scalar->new
-
-
-
-=item * Class::Accessor::Array (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::ClassAccessorArray->new
-
-
-
 =item * Moose (perl_code)
 
 Code template:
@@ -130,14 +91,6 @@ Code template:
 
 
 
-=item * raw-array (perl_code)
-
-Code template:
-
- Perl::Examples::Accessors::Array->new
-
-
-
 =item * Class::XSAccessor (perl_code)
 
 Code template:
@@ -146,11 +99,11 @@ Code template:
 
 
 
-=item * Mo (perl_code)
+=item * raw-hash (perl_code)
 
 Code template:
 
- Perl::Examples::Accessors::Mo->new
+ Perl::Examples::Accessors::Hash->new
 
 
 
@@ -162,6 +115,38 @@ Code template:
 
 
 
+=item * raw-array (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Array->new
+
+
+
+=item * Class::XSAccessor::Array (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassXSAccessorArray->new
+
+
+
+=item * raw-scalar (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Scalar->new
+
+
+
+=item * Mo (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::Mo->new
+
+
+
 =item * Moo (perl_code)
 
 Code template:
@@ -170,6 +155,22 @@ Code template:
 
 
 
+=item * Class::Accessor (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassAccessor->new
+
+
+
+=item * Class::Accessor::Array (perl_code)
+
+Code template:
+
+ Perl::Examples::Accessors::ClassAccessorArray->new
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
@@ -178,21 +179,21 @@ Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (
 
 Benchmark with default options (C<< bencher -m Accessors::Construction >>):
 
- +--------------------------+-------------+-----------+------------+---------+---------+
- | participant              | rate (/s)   | time (μs) | vs_slowest | errors  | samples |
- +--------------------------+-------------+-----------+------------+---------+---------+
- | Moose                    | 4.798e+05   | 2.084     | 1          | 3.5e-11 | 20      |
- | Mo                       | 7.3e+05     | 1.4       | 1.5        | 1.6e-09 | 21      |
- | Moo                      | 9.5e+05     | 1         | 2          | 1.7e-09 | 20      |
- | Class::Accessor          | 1.1e+06     | 0.94      | 2.2        | 1.3e-09 | 20      |
- | Mouse                    | 1.36e+06    | 0.737     | 2.83       | 4.2e-10 | 20      |
- | raw-array                | 1.57e+06    | 0.638     | 3.27       | 1.9e-10 | 23      |
- | raw-hash                 | 2e+06       | 0.51      | 4.1        | 6.5e-10 | 20      |
- | Class::Accessor::Array   | 2.04e+06    | 0.491     | 4.24       | 3.1e-10 | 23      |
- | raw-scalar               | 2.09e+06    | 0.479     | 4.35       | 2.1e-10 | 20      |
- | Class::XSAccessor        | 3.34001e+06 | 0.2994    | 6.96175    | 0       | 20      |
- | Class::XSAccessor::Array | 3.8e+06     | 0.27      | 7.8        | 9.6e-10 | 20      |
- +--------------------------+-------------+-----------+------------+---------+---------+
+ +--------------------------+-----------+-----------+------------+-----------------+---------+---------+
+ | participant              | rate (/s) | time (μs) | vs_slowest | result_size (b) | errors  | samples |
+ +--------------------------+-----------+-----------+------------+-----------------+---------+---------+
+ | Moose                    | 4.8e+05   | 2.1       | 1          | 120             | 4.2e-09 | 20      |
+ | Mo                       | 7.3e+05   | 1.4       | 1.5        | 120             | 2.1e-09 | 20      |
+ | Moo                      | 9.27e+05  | 1.08      | 1.95       | 120             | 1.5e-10 | 20      |
+ | Class::Accessor          | 1.05e+06  | 0.956     | 2.2        | 120             | 4e-10   | 25      |
+ | Mouse                    | 1.33e+06  | 0.75      | 2.8        | 120             | 4.3e-10 | 20      |
+ | raw-array                | 1.5e+06   | 0.65      | 3.2        | 64              | 1.6e-09 | 21      |
+ | raw-hash                 | 1.9e+06   | 0.52      | 4          | 120             | 7.7e-10 | 24      |
+ | Class::Accessor::Array   | 2e+06     | 0.5       | 4.2        | 64              | 1e-09   | 21      |
+ | raw-scalar               | 2.1e+06   | 0.48      | 4.4        | 72              | 1.7e-09 | 24      |
+ | Class::XSAccessor::Array | 3.13e+06  | 0.32      | 6.58       | 64              | 2.2e-10 | 22      |
+ | Class::XSAccessor        | 3.2e+06   | 0.31      | 6.8        | 120             | 7.9e-10 | 23      |
+ +--------------------------+-----------+-----------+------------+-----------------+---------+---------+
 
 =head1 DESCRIPTION
 
