@@ -1,7 +1,7 @@
 package Bencher::Scenario::Accessors::GeneratorStartup;
 
 our $DATE = '2016-03-29'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 use Bencher::ScenarioUtil::Accessors;
 
@@ -35,7 +35,7 @@ Bencher::Scenario::Accessors::GeneratorStartup - Benchmark startup of various ac
 
 =head1 VERSION
 
-This document describes version 0.01 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-29.
+This document describes version 0.02 of Bencher::Scenario::Accessors::GeneratorStartup (from Perl distribution Bencher-Scenarios-Accessors), released on 2016-03-29.
 
 =head1 SYNOPSIS
 
@@ -69,51 +69,19 @@ L<Mouse> v2.4.5
 
 =over
 
-=item * Class::XSAccessor::Array (perl_code)
-
-L<Class::XSAccessor::Array>
-
-
-
-=item * Class::Accessor (perl_code)
-
-L<Class::Accessor>
-
-
-
-=item *  (perl_code)
-
-
-
-=item *  (perl_code)
-
-
-
-=item * Class::Accessor::Array (perl_code)
-
-L<Class::Accessor::Array>
-
-
-
 =item * Moose (perl_code)
 
 L<Moose>
 
 
 
-=item *  (perl_code)
-
-
-
 =item * Class::XSAccessor (perl_code)
 
 L<Class::XSAccessor>
 
 
 
-=item * Mo (perl_code)
-
-L<Mo>
+=item *  (perl_code)
 
 
 
@@ -123,12 +91,44 @@ L<Mouse>
 
 
 
+=item *  (perl_code)
+
+
+
+=item * Class::XSAccessor::Array (perl_code)
+
+L<Class::XSAccessor::Array>
+
+
+
+=item *  (perl_code)
+
+
+
+=item * Mo (perl_code)
+
+L<Mo>
+
+
+
 =item * Moo (perl_code)
 
 L<Moo>
 
 
 
+=item * Class::Accessor (perl_code)
+
+L<Class::Accessor>
+
+
+
+=item * Class::Accessor::Array (perl_code)
+
+L<Class::Accessor::Array>
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
@@ -140,15 +140,15 @@ Benchmark with default options (C<< bencher -m Accessors::GeneratorStartup >>):
  +--------------------------+-----------+------------------------+------------+---------+---------+
  | participant              | time (ms) | mod_overhead_time (ms) | vs_slowest | errors  | samples |
  +--------------------------+-----------+------------------------+------------+---------+---------+
- | Moose                    | 1.8e+02   | 175                    | 1          | 0.0012  | 20      |
- | Mouse                    | 26        | 21                     | 7          | 7.7e-05 | 20      |
- | Moo                      | 20        | 15                     | 9          | 7.7e-05 | 20      |
- | Class::XSAccessor::Array | 13        | 8                      | 14         | 5.4e-05 | 20      |
- | Class::Accessor          | 1e+01     | 5                      | 1e+01      | 0.00016 | 20      |
- | Class::XSAccessor        | 12        | 7                      | 15         | 4.7e-05 | 20      |
- | Mo                       | 7         | 2                      | 26         | 3.1e-05 | 20      |
- | Class::Accessor::Array   | 6.8       | 1.8                    | 27         | 1.2e-05 | 20      |
- | perl -e1 (baseline)      | 5         | 0                      | 4e+01      | 8.4e-05 | 20      |
+ | Moose                    | 1.9e+02   | 185                    | 1          | 0.0016  | 20      |
+ | Mouse                    | 28        | 23                     | 6.7        | 0.00011 | 20      |
+ | Moo                      | 21        | 16                     | 9          | 4.3e-05 | 22      |
+ | Class::XSAccessor::Array | 13        | 8                      | 14         | 0.00011 | 20      |
+ | Class::XSAccessor        | 13        | 8                      | 15         | 7.6e-05 | 20      |
+ | Class::Accessor          | 12        | 7                      | 15         | 2.4e-05 | 20      |
+ | Mo                       | 8         | 3                      | 2e+01      | 9.5e-05 | 20      |
+ | Class::Accessor::Array   | 6.8       | 1.8                    | 28         | 1.3e-05 | 20      |
+ | perl -e1 (baseline)      | 5         | 0                      | 4e+01      | 4.6e-05 | 20      |
  +--------------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
